@@ -19,6 +19,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 // own
 #include <config-kscreenlocker.h>
+// KF
+#include <KLibexec>
 // Qt
 #include <QtTest>
 // system
@@ -88,7 +90,7 @@ void KillTest::testKill()
 {
     QProcess greeter(this);
     greeter.setReadChannel(QProcess::StandardOutput);
-    greeter.start(QStringLiteral(KSCREENLOCKER_GREET_BIN), QStringList({QStringLiteral("--testing")}));
+    greeter.start(KLibexec::path(KSCREENLOCKER_GREET_BIN_REL), QStringList({QStringLiteral("--testing")}));
     QVERIFY(greeter.waitForStarted());
 
     // wait some time till it's really set up
@@ -96,7 +98,7 @@ void KillTest::testKill()
 
     // now kill
     QFETCH(int, signal);
-    kill(greeter.pid(), signal);
+    kill(greeter.processId(), signal);
 
     QFETCH(bool, expectedQuit);
     QCOMPARE(greeter.waitForFinished(1000), expectedQuit);
@@ -165,12 +167,12 @@ void KillTest::testImmediateKill()
     // this test ensures that the greeter indicates crashexit when a signal is sent to the greeter
     // before it had time to properly setup
     QProcess greeter(this);
-    greeter.start(QStringLiteral(KSCREENLOCKER_GREET_BIN), QStringList({QStringLiteral("--testing")}));
+    greeter.start(KLibexec::path(KSCREENLOCKER_GREET_BIN_REL), QStringList({QStringLiteral("--testing")}));
     QVERIFY(greeter.waitForStarted());
 
     // now kill
     QFETCH(int, signal);
-    kill(greeter.pid(), signal);
+    kill(greeter.processId(), signal);
 
     QVERIFY(greeter.waitForFinished());
     QCOMPARE(greeter.exitStatus(), QProcess::CrashExit);
